Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1483)

Unified Diff: content/renderer/media/android/stream_texture_factory.h

Issue 2192823004: Update StreamTextureProxy to accept a base::Closure (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Addressing comments Created 4 years, 5 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | content/renderer/media/android/stream_texture_factory.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: content/renderer/media/android/stream_texture_factory.h
diff --git a/content/renderer/media/android/stream_texture_factory.h b/content/renderer/media/android/stream_texture_factory.h
index cf1d874d8337c041680c2dc8595fe7187316703c..9f79634a21775402eb70aadd7e3fb40c61df3e22 100644
--- a/content/renderer/media/android/stream_texture_factory.h
+++ b/content/renderer/media/android/stream_texture_factory.h
@@ -36,12 +36,12 @@ class StreamTextureProxy : public StreamTextureHost::Listener {
public:
~StreamTextureProxy() override;
- // Initialize and bind to the loop, which becomes the thread that
- // a connected client will receive callbacks on. This can be called
- // on any thread, but must be called with the same loop every time.
- void BindToLoop(int32_t stream_id,
- cc::VideoFrameProvider::Client* client,
- scoped_refptr<base::SingleThreadTaskRunner> loop);
+ // Initialize and bind to the loop, which becomes the thread that the provided
+ // callback will be run on. This can be called on any thread, but must be
+ // called with the same loop every time.
+ void BindToTaskRunner(int32_t stream_id,
+ const base::Closure& received_frame_cb,
+ scoped_refptr<base::SingleThreadTaskRunner> loop);
watk 2016/08/01 22:30:03 s/loop/task_runner/
tguilbert 2016/08/01 23:03:18 Done.
// StreamTextureHost::Listener implementation:
void OnFrameAvailable() override;
@@ -58,9 +58,9 @@ class StreamTextureProxy : public StreamTextureHost::Listener {
const std::unique_ptr<StreamTextureHost> host_;
// Protects access to |client_| and |loop_|.
base::Lock lock_;
- cc::VideoFrameProvider::Client* client_;
+ base::Closure received_frame_cb_;
scoped_refptr<base::SingleThreadTaskRunner> loop_;
DISALLOW_IMPLICIT_CONSTRUCTORS(StreamTextureProxy);
« no previous file with comments | « no previous file | content/renderer/media/android/stream_texture_factory.cc » ('j') | no next file with comments »
@@ -58,9 +58,9 @@ class StreamTextureProxy : public StreamTextureHost::Listener {
const std::unique_ptr<StreamTextureHost> host_;
- // Protects access to |client_| and |loop_|.
+ // Protects access to |received_frame_cb_| and |loop_|.
base::Lock lock_;

Powered by Google App Engine
This is Rietveld 408576698